<?php 
/** 
*
* @package phpBB3
* @version $Id: sitemap_functions.php 2007-11-26 Joshua2100 $
* @copyright (c) 2007 Joshua www.commexcomputers.com
* @license http://opensource.org/licenses/gpl-license.php GNU Public License 
*
*/

if (!defined('IN_PHPBB'))
{
	exit;
}
// start
function clean_for_xml($string) 
{
	$before = array('&', "'", '"', '>', '<');
	$after = array('&amp;', '&apos;', '&quot;', '&gt;', '&lt;');
	$string = str_replace($before, $after, $string);
	return $string;
}

function write_map($xmlcontent, $type, $zipped) 
{
	global $phpbb_root_path, $user;

	$xml = '<?xml version="1.0" encoding="UTF-8"?>'."\r\n";
	$xml .= '<urlset xmlns="http://www.sitemaps.org/schemas/sitemap/0.9">'."\r\n";
	$xml .= $xmlcontent;
	$xml .= '</urlset>';
	
	$xmlindex = '<?xml version="1.0" encoding="UTF-8"?>
   				<sitemapindex xmlns="http://www.sitemaps.org/schemas/sitemap/0.9">'
				.$xmlcontent.'
				</sitemapindex>';
				
	switch($type)
	{
	case 'forum':
		$filename = $phpbb_root_path . 'forum_sitemap.xml';
		$contents = $xml;
	break;
	case 'topic':
		$filename = $phpbb_root_path . 'topic_sitemap.xml';
		$contents = $xml;
	break;
	case 'index':
		$filename = $phpbb_root_path . 'sitemap_index.xml';
		$contents = $xmlindex;
	break;
	}
	if (is_writable($filename.'.gz') && ($zipped == true)) 
	{
		$zp = gzopen($filename.'.gz', "w9");
		gzwrite($zp, $contents);
		gzclose($zp);
	}
	elseif (is_writable($filename)) 
	{
		$fp = fopen($filename, "w");
		fwrite($fp, $contents);
		fclose($fp);
	}
	else
	{
		return $error = true;
	}
}

function topic_map($seomod) 
{
	global $db, $user;
	
	$t_xml = null;
	
	$sql = 'SELECT topic_id, topic_title, topic_last_post_time FROM '. TOPICS_TABLE;
	$result = $db->sql_query($sql);
	
	while ($data = $db->sql_fetchrow($result)) 
	{
		$lastpost = $user->format_date($data['topic_last_post_time'], "Y-m-d");
		$t_xml .= '<url>'."\r\n";
		
		if ($seomod == true) 
		{
			$topicname = clean_url($data['topic_title']);
			$topicname = clean_for_xml($topicname);
			$t_xml .= '<loc>'.FORUM_DOMAIN_ROOT.$topicname.'-t'.$data['topic_id'].'.html</loc>'."\r\n";
		} 
		else 
		{
			$t_xml .= '<loc>'.FORUM_DOMAIN_ROOT.'viewtopic.php?t='.$data['topic_id'].'</loc>'."\r\n";
		}
		$t_xml .= '<lastmod>'.$lastpost.'</lastmod>'."\r\n";
		$t_xml .= '<changefreq>daily</changefreq>'."\r\n";
		$t_xml .= '<priority>0.5</priority>'."\r\n";
		$t_xml .= '</url>'."\r\n";
	}		
	return $t_xml;
}

function forum_map($seomod) 
{
	global $db;
	
	$f_xml = null;
	
	$sql = 'SELECT forum_id, forum_name FROM '. FORUMS_TABLE;
	$result = $db->sql_query($sql);
	
	while ($data = $db->sql_fetchrow($result)) 
	{
		$f_xml .= '<url>'."\r\n";
		if ($seomod == true) 
		{
			$forumname = clean_url($data['forum_name']);
			$forumname = clean_for_xml($forumname);
			$f_xml .= '<loc>'.FORUM_DOMAIN_ROOT.$forumname.'-f'.$data['forum_id'].'.html</loc>'."\r\n";
		} 
		else 
		{
			$f_xml .= '<loc>'.FORUM_DOMAIN_ROOT.'viewforum.php?f='.$data['forum_id'].'</loc>'."\r\n";
		}
		
		$f_xml .= '<changefreq>daily</changefreq>'."\r\n";
		$f_xml .= '<priority>0.5</priority>'."\r\n";
		
		$f_xml .= '</url>'."\r\n";
	}
	return $f_xml;
}

function map_index() {
	$indfiles = array('topic_sitemap.xml', 'forum_sitemap.xml');
	$data = current($indfiles);
	$i_xml = '<sitemap><loc>'.FORUM_DOMAIN_ROOT.$data.'</loc></sitemap>';
	while ($data = next($indfiles)) 
	{	
	$i_xml .= '<sitemap><loc>'.FORUM_DOMAIN_ROOT.$data.'</loc></sitemap>';
	}
	return $i_xml;
}

function pinggooglesitemaps($url_xml)
// @author     J de Silva  <giddomains@gmail.com>
// @link       http://www.gidnetwork.com/b-54.html  PHP function to ping Google Sitemaps
{
	global $user;
	$status = 0;
	$google = 'www.google.com';
	if( $fp=@fsockopen($google, 80) )
	{
		$req =  'GET /webmasters/sitemaps/ping?sitemap=' .
				urlencode( $url_xml ) . " HTTP/1.1\r\n" .
				"Host: $google\r\n" .
				"User-Agent: Mozilla/5.0 (compatible; " .
				PHP_OS . ") PHP/" . PHP_VERSION . "\r\n" .
				"Connection: Close\r\n\r\n";
		fwrite( $fp, $req );
		while( !feof($fp) )
		{
			if( @preg_match('~^HTTP/\d\.\d (\d+)~i', fgets($fp, 128), $m) )
			{
				$status = intval( $m[1] );
				 break;
			}
		}
	fclose( $fp );
	}
	if ($status != '200') 
	{
		trigger_error($user->lang['MAP_GOOGLE_PING'] . '<br />' . $status . $user->lang['PING_ERROR'] . adm_back_link($this->u_action), E_USER_WARNING);
	}
}
?>